<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 * Component for handling all Notifications in system.
 * If need to notify all Notificators about event invoked method Yii::app()->notificationManager->notifyAbout($notification);
 */
class NotificationManager extends CApplicationComponent
{

    public $cacheTime;

    /**
     * @var array notificators array
     */
    private $_notificators = array();

    /**
     * Public setter
     *
     * @param array $config configuration array
     *
     * @return void
     */
    public function setNotificators($config)
    {
        foreach ($config as $name => $notificator) {
            $this->_notificators[$name] = $notificator;
        }
    }

    /**
     * Public getter
     *
     * @return array
     */
    public function getNotificators()
    {
        return $this->_notificators;
    }

    /**
     * Add notificator
     *
     * @param string       $name              notificator name, if exists will be replaced
     * @param array|object $notificatorConfig notificator config array or object
     *
     * @return void
     */
    public function addNotificator($name, $notificatorConfig)
    {
        if (is_array($notificatorConfig)) {
            $notificatorConfig = Yii::createComponent($notificatorConfig);
            $notificatorConfig->init();
            $this->_notificators[$name] = $notificatorConfig;
        } elseif ($notificatorConfig instanceof CComponent) {
            $this->_notificators[$name] = $notificatorConfig;
        }
    }

    /**
     * Remove notificator
     *
     * @param string $name notificator name
     *
     * @return void
     */
    public function removeNotificator($name)
    {
        unset($this->_notificators[$name]);
    }

    /**
     * Init manager
     *
     * @return void
     */
    public function init()
    {
        foreach ($this->_notificators as $name => $notificator) {
            $this->addNotificator($name, $notificator);
        }
        parent::init();
    }

    /**
     * Method which starts handle $notification by all notificators
     *
     * @param Notification $notification occurred notification
     *
     * @return void
     */
    public function notifyAbout(Notification $notification)
    {
        foreach ($this->_notificators as $notificator) {
            $notificator->notify($notification);
        }
    }

}