<?php

/**
 * This is the model class for table "gportal_apalines_news".
 *
 * The followings are the available columns in table 'gportal_apalines_news':
 * @property integer $id
 * @property string $title
 * @property integer $ndate
 * @property string $channel
 * @property string $docid
 * @property integer $background_news
 * @property integer $related_maindoc_id
 * @property string $place
 * @property string $source
 * @property string $teaser
 * @property string $content
 * @property string $filename
 * @property string $author
 * @property string $keywords
 * @property integer $deleted
 * @property integer $created
 * @property integer $updated
 * @property string $xml_filename
 * @property string $apa_id
 */
class ApalinesNews extends APAActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return ApalinesNews the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'gportal_apalines_news';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('ndate, background_news, related_maindoc_id, deleted, created, updated', 'numerical', 'integerOnly'=>true),
			array('title, channel, docid, place, source, author, xml_filename, apa_id', 'length', 'max'=>255),
			array('filename', 'length', 'max'=>64),
			array('teaser, content, keywords', 'safe'),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, title, ndate, channel, docid, background_news, related_maindoc_id, place, source, teaser, content, filename, author, keywords, deleted, created, updated, xml_filename', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
            'bg_news'=>array(self::HAS_MANY, 'ApalinesNews', 'related_maindoc_id'),
            'multimedia'=>array(self::HAS_MANY, 'ApalinesMM', 'related_maindoc_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'title' => 'Title',
			'ndate' => 'Ndate',
			'channel' => 'Channel',
			'docid' => 'Docid',
			'background_news' => 'Background News',
			'related_maindoc_id' => 'Related Maindoc',
			'place' => 'Place',
			'source' => 'Source',
			'teaser' => 'Teaser',
			'content' => 'Content',
			'filename' => 'Filename',
			'author' => 'Author',
			'keywords' => 'Keywords',
			'deleted' => 'Deleted',
			'created' => 'Created',
			'updated' => 'Updated',
            'xml_filename' => 'XML filename',
            'apa_id' => 'APA id'
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('title',$this->title,true);
		$criteria->compare('ndate',$this->ndate);
		$criteria->compare('channel',$this->channel,true);
		$criteria->compare('docid',$this->docid,true);
		$criteria->compare('background_news',$this->background_news);
		$criteria->compare('related_maindoc_id',$this->related_maindoc_id);
		$criteria->compare('place',$this->place,true);
		$criteria->compare('source',$this->source,true);
		$criteria->compare('teaser',$this->teaser,true);
		$criteria->compare('content',$this->content,true);
		$criteria->compare('filename',$this->filename,true);
		$criteria->compare('author',$this->author,true);
		$criteria->compare('keywords',$this->keywords,true);
		$criteria->compare('deleted',$this->deleted);
		$criteria->compare('created',$this->created);
		$criteria->compare('updated',$this->updated);
        $criteria->compare('xml_filename',$this->xml_filename, true);
        $criteria->compare('apa_id',$this->apa_id, true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
    /**
     * Function removes files and files of background news
     */
    public function deleteFiles($with_build = false) {

        if (isset($this->bg_news)) {
            foreach ($this->bg_news as $bg) {
                if (isset($bg->multimedia)) {
                    foreach ($bg->multimedia as $mm) {
                        if ($with_build) {
                            $mm->delete();
                        } else {
                            $mm->deleteFiles();
                        }
                    }
                }
            }
        }
        if (isset($this->multimedia)) {
            foreach ($this->multimedia as $mm) {
                if ($with_build) {
                    $mm->delete();
                } else {
                    $mm->deleteFiles();
                }
            }
        }
    }
    /**
     * Function removes background news before record is deleted
     */
    public function beforeDelete() {

        $this->deleteFiles(true);
        if (isset($this->bg_news)) {
            foreach ($this->bg_news as $bg) {
                $bg->delete();
            }
        }
        return parent::beforeDelete();
    }
}