<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 * Widget for viewing navigation tree
 */

class PersonalizedContentWidget extends BaseJuiWidget
{
    /**
     * @var $folderIds array contains folder IDs of content to show
     */
    public $folderIds = array();

    /**
     * @var $tplString string template string for repeating content
     */
    public $tplString = '';

    /**
     * language
     * @var lang
     */
    public $lang = '';

    /**
     * How many results should be skipped. Used fot pagination
     * @var string
     */
    public $offset = 0;

    /**
     * total matches found, exlc. status
     * @var int
     */
    public $totalQty = 0;

    /**
     * how many results show per page
     * @var int
     */
    public $perPage = null;

    /**
     * Base href for current page
     * @var int
     */
    public $baseHref = '';

    /**
     * @var bool $usePersonalisation defines if personalisation should be performed
     */
    public $usePersonalisation = true;
    /**
     * @var string GCC request params. Comma separated.
     */
    public $gccRequestParams;

    /**
     * @var string $sorting contains sorting expression
     */
    public $sorting;
    /**
     * Initializes the widget.
     *
     * @return void
     */
    public function init()
    {
        //die('this is init');
    }

    /**
     * renders view
     *
     * @throws Exception
     * @return void
     */
    public function run()
    {
        $tag = '';
        if (!empty($_GET['folderIds']) && !empty($_GET['tag'])) {
            preg_match_all('/([0-9]+)/', $_GET['folderIds'], $folderIds);

            array_walk(
                $folderIds[0],
                function(&$item)
                {
                    $item = '10002.'.$item;
                }
            );

            $this->folderIds = $folderIds[0];
            $tag = $_GET['tag'];
        }
        /*
         * Get values from widget option for PersonalizedContent
         * if it is set otherwise it will be taken from module
         */
        $gccRequestParams = null;
        if(isset($this->gccRequestParams)){
            $gccRequestParams = $this->gccRequestParams;
        }
        $sorting = null;
        if(isset($this->sorting)){
            $sorting = $this->sorting;
        }

        if (!empty($this->folderIds) && !empty($this->tplString)) {
            $content = new PersonalizedContent($this->folderIds, $this->usePersonalisation, $tag, $gccRequestParams , $sorting);
        } else {
            throw new Exception('PersonalizedContentWidget error: folderIds and tplString are required parameters and can`t be blank ');
        }

        $this->loadBaseHref();
        $this->offset = (int)Yii::app()->request->getQuery('offset', 0);

        if (!empty($content->data)) {
            $this->totalQty = count($content->data);
            $this->perPage = (isset($this->perPage) && $this->perPage > 0)? $this->perPage : Yii::app()->getModule('personalizedContent')->perPage;

            /*  check if offet is in range of results quantity */
            if ($this->offset>=$this->totalQty || $this->offset<0) {
                $this->offset = 0;
            }

            /* calculating pagination */
            $content->data = array_slice($content->data, $this->offset, $this->perPage);

            $this->lang = substr(Yii::app()->language, 0, 2);
            $this->render('PersonalizedContentWidget', array('contentList'=>$content->data));
        }
    }

    /**
     * Finds out current base href
     *
     * @return void
     */
    public function loadBaseHref()
    {
        $this->baseHref = Yii::app()->request->pathInfo;

        if (!empty(Yii::app()->request->queryString)) {
            $getParams = explode('&', Yii::app()->request->queryString);

            $params = array();
            foreach ($getParams as $param) {
                $param = explode('=', $param);
                if ($param[0]=='offset') {
                    continue;
                }
                $params[] = $param[0].'='.$param[1];
            }
            if (!empty($params)) {
                $this->baseHref .= '?'.implode('&', $params).'&';
            } else {
                $this->baseHref .= '?';
            }
        } else {
            $this->baseHref .= '?';
        }

        $this->baseHref = Yii::app()->CreateUrl($this->baseHref);
    }
}