<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 * This model is ActiveRecord which represents single remembered page in database.
 *
 * The followings are the available columns in table '{{remembered_pages}}':
 * @property integer $id
 * @property string $collection_id
 * @property string $page_id
 * @property string $url
 * @property array  $additional
 * @property string $image
 * @property string $title
 * @property string $created
 */

class RememberedPage extends CActiveRecord
{

    /**
     * Returns the static model of the specified AR class.
     *
     * @param string $className active record class name
     *
     * @return array|CActiveRecord
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * Returns the name of the associated database table.
     * By default this method returns the class name as the table name.
     * You may override this method if the table is not named after this convention.
     *
     * @return string the table name
     */
    public function tableName()
    {
        return '{{remembered_pages}}';
    }

    /**
     * Returns the validation rules for attributes.
     *
     * @return array
     */
    public function rules()
    {
        return array(
            array('created', 'default', 'value' => AppHelper::mysqlDate()),
            array('url, title, page_id, collection_id','required'),
            array('page_id, title','length', 'max'=>255),
            array('additional', 'safe'),
            array('created', 'type', 'type'=>'datetime', 'datetimeFormat' => 'yyyy-MM-dd HH:mm:ss'),
            array('id, url, title, page_id, collection_id, created','safe', 'on'=>'search'),
        );
    }


    public function getAttributeLabel($name)
    {
        return RememberModule::t(parent::getAttributeLabel($name));
    }

    protected function beforeSave()
    {
        if($this->additional !== null) {
            $this->additional = serialize($this->additional);
        }
        return parent::beforeSave();
    }

    protected function afterSave()
    {
        if($this->additional !== null) {
            $this->additional = unserialize($this->additional);
        }
    }
    
    protected function afterFind()
    {
        if($this->additional !== null) {
            $this->additional = unserialize($this->additional);
        }
    }

    public function getFbSharerUrl(){
        $shareUrl = "http://www.facebook.com/sharer.php?s=100&p[title]=%title%&p[url]=%url%&p[summary]=%summary%&p[images][0]=%image%";
        return str_replace(
            array('%title%', '%url%', '%summary%', '%image%'), 
            array($this->title, $this->url, $this->title, $this->image), $shareUrl);
    }
    /**
     * Search
     *
     * @return CActiveDataProvider
     */
    public function search($pageSize = 10, $collection_id = null)
    {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id, true);
        $criteria->compare('page_id', $this->page_id, true);
        $criteria->compare('url', $this->url, true);
        $criteria->compare('title', $this->title, true);
        $criteria->compare('created', $this->created, true);
        $criteria->compare('collection_id', $collection_id);
        
        $pagination = new CPagination($this->count($criteria));
        $pagination->applyLimit($criteria);
        $pagination->setPageSize($pageSize);
        
        return new CActiveDataProvider($this, array('criteria' => $criteria,'pagination' => $pagination));
    }
}
